Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(168)

Unified Diff: content/renderer/render_widget.h

Issue 11364221: Fixing RenderingStats vs WebRenderingStats mess (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/gpu/gpu_benchmarking_extension.cc ('k') | content/renderer/render_widget.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/render_widget.h
diff --git a/content/renderer/render_widget.h b/content/renderer/render_widget.h
index 28d961d7ecf4f529008b61d6e1d838593d449a92..6e4d85934909e68d375a9acec0e7f574b0effa7b 100644
--- a/content/renderer/render_widget.h
+++ b/content/renderer/render_widget.h
@@ -14,11 +14,11 @@
#include "base/memory/scoped_ptr.h"
#include "base/time.h"
#include "base/timer.h"
+#include "cc/rendering_stats.h"
#include "content/common/content_export.h"
#include "content/renderer/paint_aggregator.h"
#include "ipc/ipc_listener.h"
#include "ipc/ipc_sender.h"
-#include "third_party/WebKit/Source/Platform/chromium/public/WebRenderingStats.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebCompositionUnderline.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebPopupType.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebTextDirection.h"
@@ -44,6 +44,7 @@ class SyncMessage;
namespace WebKit {
class WebGestureEvent;
class WebMouseEvent;
+struct WebRenderingStatsImpl;
class WebTouchEvent;
}
@@ -151,11 +152,11 @@ class CONTENT_EXPORT RenderWidget
// pending moves don't try to reference it.
void CleanupWindowInPluginMoves(gfx::PluginWindowHandle window);
// Fills in a WebRenderingStats struct containing information about
// rendering, e.g. count of frames rendered, time spent painting.
// This call is relatively expensive in threaded compositing mode,
// as it blocks on the compositor thread.
- void GetRenderingStats(WebKit::WebRenderingStats&) const;
+ void GetRenderingStats(WebKit::WebRenderingStatsImpl&) const;
// Fills in a GpuRenderingStats struct containing information about
// GPU rendering, e.g. count of texture uploads performed, time spent
@@ -592,7 +593,7 @@ class CONTENT_EXPORT RenderWidget
bool has_disable_gpu_vsync_switch_;
base::TimeTicks last_do_deferred_update_time_;
- WebKit::WebRenderingStats software_stats_;
+ cc::RenderingStats software_stats_;
// UpdateRect parameters for the current compositing pass. This is used to
// pass state between DoDeferredUpdate and OnSwapBuffersPosted.
« no previous file with comments | « content/renderer/gpu/gpu_benchmarking_extension.cc ('k') | content/renderer/render_widget.cc » ('j') | no next file with comments »
@@ -151,11 +152,11 @@ class CONTENT_EXPORT RenderWidget
// pending moves don't try to reference it.
void CleanupWindowInPluginMoves(gfx::PluginWindowHandle window);
- // Fills in a WebRenderingStats struct containing information about
+ // Fills in a WebRenderingStatsImpl struct containing information about
// rendering, e.g. count of frames rendered, time spent painting.
// This call is relatively expensive in threaded compositing mode,

Powered by Google App Engine
This is Rietveld 408576698